# Initiative Modeling Guidelines
### On this page
  * [Definition](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines#definition)
  * [Description](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines#description)
  * [Initiative Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines#initiative-fact-sheet-subtypes)
  * [Guidelines and Best Practices](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines#guidelines-and-best-practices)
  * [How to Model Initiatives in the Context of Large Transformation Programs (with SAP LeanIX Architecture and Road Map Planning)](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines#how-to-model-initiatives-in-the-context-of-large-transformation-programs-\(with-sap-leanix-architecture-and-road-map-planning\))
  * [Antipatterns](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines#antipatterns)
  * [Applicable Use Cases](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines#applicable-use-cases)
  * [Insights from Initiative Fact Sheet](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines#insights-from-initiative-fact-sheet)
  * [Related Information](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines#related-information)


Learn how to model initiatives. This includes best practices and applicable use cases, and common antipatterns.
